@@ -34,28 +34,43 @@ typedef struct
 
 typedef struct
 {
-    time_t mtime;
-    GnomeVFSFileSize size;
+    time_t file_time;
+    GnomeVFSFileSize file_size;
 } LogStats;
 
+typedef struct TreePathRange
+{
+  GtkTreePath *first;
+  GtkTreePath *last;
+}TreePathRange;
+
 typedef struct _log Log;
 struct _log
 {
 	char *name;
 	char *display_name;
-	LogStats *lstats;
+	LogStats *stats;
 
-    GList *days;
+    GSList *days;
     gchar **lines;
 	gint selected_line_first;
 	gint selected_line_last;
 	gint total_lines; /* no of lines in the file */
     gint displayed_lines; /* no of lines displayed now */
 
+	/* Monitor info */
+	GnomeVFSFileSize mon_offset;
+	GnomeVFSMonitorHandle *mon_handle;
+    GnomeVFSHandle *mon_file_handle;
+	gboolean monitored;
+    gboolean needs_refresh;
+
 	gboolean first_time;
-	GtkTreePath *current_path;
     GtkTreeModel *model;
     GtkTreeModelFilter *filter;
+    GList *bold_rows_list;
+	TreePathRange selected_range;
+    GtkTreePath *visible_first;
 
 	int versions;
 	int current_version;
@@ -63,12 +78,6 @@ struct _log
 	Log *older_logs[5];
 	Log *parent_log;
 	
-	/* Monitor info */
-	GnomeVFSFileOffset mon_offset;
-	GnomeVFSMonitorHandle *mon_handle;
-    GnomeVFSHandle *mon_file_handle;
-	gboolean monitored;
-
     gpointer window;
 };
 
@@ -77,5 +86,7 @@ Log *log_open (char *filename, gboolean show_error);
 gboolean log_read_new_lines (Log *log);
 gboolean log_unbold (gpointer data);
 void log_close (Log * log);
+gchar *log_extract_filename (Log *log);
+gchar *log_extract_dirname (Log *log);
 
 #endif /* __LOGRTNS_H__ */
